import * as React from 'react';
import * as ReactDom from 'react-dom';
import { Version } from '@microsoft/sp-core-library';
import {
  IPropertyPaneConfiguration,
  PropertyPaneTextField
} from '@microsoft/sp-property-pane';
import { BaseClientSideWebPart } from '@microsoft/sp-webpart-base';

import * as strings from 'FabricUiGroupedListWebPartStrings';
import FabricUiGroupedList from './components/FabricUiGroupedList';
import { IFabricUiGroupedListProps } from './components/IFabricUiGroupedListProps';

export interface IFabricUiGroupedListWebPartProps {
  description: string;
}

export default class FabricUiGroupedListWebPart extends BaseClientSideWebPart <IFabricUiGroupedListWebPartProps> {

  public render(): void {
    const element: React.ReactElement<IFabricUiGroupedListProps> = React.createElement(
      FabricUiGroupedList,
      {
        description: this.properties.description,
        SiteURL:this.context.pageContext.web.absoluteUrl
      }
    );

    ReactDom.render(element, this.domElement);
  }

  protected onDispose(): void {
    ReactDom.unmountComponentAtNode(this.domElement);
  }

  protected get dataVersion(): Version {
    return Version.parse('1.0');
  }

  protected getPropertyPaneConfiguration(): IPropertyPaneConfiguration {
    return {
      pages: [
        {
          header: {
            description: strings.PropertyPaneDescription
          },
          groups: [
            {
              groupName: strings.BasicGroupName,
              groupFields: [
                PropertyPaneTextField('description', {
                  label: strings.DescriptionFieldLabel
                })
              ]
            }
          ]
        }
      ]
    };
  }
}
