import * as React from 'react';
import styles from './FabricUiGroupedList.module.scss';
import { Icon, initializeIcons } from "office-ui-fabric-react";
import { Selection, SelectionMode } from 'office-ui-fabric-react/lib/Selection';
import { GroupedList, IGroup, IGroupRenderProps, IGroupHeaderProps, GroupHeader } from 'office-ui-fabric-react/lib/GroupedList';
import { IFabricUiGroupedListProps } from './IFabricUiGroupedListProps';
import { escape, groupBy, findIndex } from '@microsoft/sp-lodash-subset';

export interface GroupedListStates {
  items: IDocument[];
  result: any;

}

export interface IDocument {
  Title: any;
  IconCategory: any;
}

export default class FabricUiGroupedList extends React.Component<IFabricUiGroupedListProps, GroupedListStates> {
  private _selection: Selection;
  constructor(props) {

    super(props);
    initializeIcons();
    this.state = {
      items: [],
      result: [],
    };
  }
  public async componentWillMount() {
    let groupedlistitems = await GetGroupedListData(this.props.SiteURL);
    console.log(groupedlistitems);
    this.setState({ result: groupedlistitems });

  }

  private _generateIGroupsFromArray(sortedItems: any[]): IGroup[] {
    const groupedByIconCategory: any = groupBy(sortedItems, (i: any) => i.IconCategory);
    let groups: IGroup[] = [];
    for (const IconCategory in groupedByIconCategory) {
      groups.push({
        name: IconCategory,
        key: IconCategory,
        startIndex: findIndex(sortedItems, (i: any) => i.IconCategory === IconCategory),
        count: groupedByIconCategory[IconCategory].length,
         isCollapsed:findIndex(sortedItems, (i: any) => i.IconCategory === IconCategory)==0? false:true
      });
    }
    return groups;
  }
  public render(): React.ReactElement<IFabricUiGroupedListProps> {
    return (
      <div>
        <h3>Fabric UI Grouped List with Icon Category</h3>
        <hr />
        <GroupedList
          className={styles.groupcolor}
          items={this.state.result}
          onRenderCell={this._onRenderCell}
          groups={this._generateIGroupsFromArray(this.state.result)}
          groupProps={groupedListProps}
          selection={this._selection}
          selectionMode={SelectionMode.none}
        />
      </div>

    );
  }

  private _onRenderCell = (_nestingDepth: number, item: IDocument, itemIndex: number): JSX.Element => {
    return (
      <div>
        <span style={{ fontSize: "large", paddingLeft: "25px" }}>
          {item.Title}</span>
        <br />
      </div>

    );
  }
}

export const GetGroupedListData = async (webURL) => {
  let items = [];
  await fetch(`${webURL}/_api/web/lists/Getbytitle('FabricUIGroupedList')/items`, {
    method: 'GET',
    mode: 'cors',
    credentials: 'include',
    headers: new Headers({
      'Content-Type': 'application/json',
      'Accept': 'application/json',
      'Access-Control-Allow-Origin': '*',
      'Cache-Control': 'no-cache',
      'pragma': 'no-cache',
    }),
  }).then(async (response) => await response.json())
    .then(async (data) => {
      console.log(data);
      if (data.value.length > 0) {
        for (let i = 0; i < data.value.length; i++) {
          items.push({
            Title: data.value[i].Title,
            IconCategory: data.value[i].IconCategory,

          });
        }
      }
    }).catch(error => console.error(error));
  return await items;
};

const onRenderHeader = (props?: IGroupHeaderProps): JSX.Element | null => {

  if (props) {
    const toggleCollapse = (): void => {
      props.onToggleCollapse!(props.group!);
    };
    return (
      <div>
        <Icon style={{marginBottom:"10px", fontSize: 25, cursor: "pointer" }} iconName={"ChevronRightSmall"} onClick={toggleCollapse}></Icon>
        <Icon
          style={{ paddingLeft: "16px", fontSize: 37, cursor: "pointer" }} iconName={props.group.name}
          onClick={toggleCollapse}
        >
          {props.group!.isCollapsed ? 'Expand' : 'Collapse'}
        </Icon>

      </div>
    );
  }

  return null;
};

const groupedListProps = {
  onRenderHeader
};
